.. _papers:

Papers
------

The following papers use **PyAutoLens**:

`Likelihood-free MCMC with Amortized Approximate Likelihood Ratios <https://arxiv.org/abs/1903.04057>`_

`Deep Learning the Morphology of Dark Matter Substructure <https://arxiv.org/abs/1909.07346>`_

`The molecular-gas properties in the gravitationally lensed merger HATLAS J142935.3-002836 <https://arxiv.org/abs/1904.00307>`_

`Galaxy structure with strong gravitational lensing: decomposing the internal mass distribution of massive elliptical galaxies <https://arxiv.org/abs/1901.07801>`_

`Novel Substructure & Superfluid Dark Matter <https://arxiv.org/abs/1901.03694>`_

`CO, H2O, H2O+ line & dust emission in a z = 3.63 strongly lensed starburst merger at sub-kiloparsec scales <https://arxiv.org/abs/1903.00273>`_

`Subaru FOCAS IFU observations of two z=0.12 strong-lensing elliptical galaxies from SDSS MaNGA <https://arxiv.org/abs/1911.06338>`_

`MNELLS: The MUSE Nearby Early-Type Galaxy Lens Locator Survey <https://arxiv.org/abs/2002.07191>`_